package ComoponentesJavaFX;

import javax.swing.JOptionPane;

import javafx.application.Application;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.geometry.Insets;
import javafx.scene.Scene;
import javafx.scene.control.*;
import javafx.scene.control.TableColumn.CellEditEvent;
import javafx.scene.control.cell.PropertyValueFactory;
import javafx.scene.control.cell.TextFieldTableCell;
import javafx.scene.layout.HBox;
import javafx.scene.layout.VBox;
import javafx.scene.text.Font;
import javafx.stage.Stage;
import javafx.util.converter.DoubleStringConverter;
import javafx.util.converter.IntegerStringConverter;

public class UsoTableViewEditable extends Application {

	public void start(Stage primaryStage) {

		try {
			
			
			Label lblCabecera = new Label("Lista de Películas");
			lblCabecera.setFont(new Font("Arial",20));
			
			TablaPeliculas = new TableView<peliculasTableView>();
			//Establece la tabla como editabla
			TablaPeliculas.setEditable(true);
			
			TablaPeliculas.setItems(cargaDatos());
			
			//Columna del titulo
			TableColumn<peliculasTableView,String> colTitulo = new TableColumn("Titulo");
			//Ancho columna
			colTitulo.setMinWidth(290);
			//Valor que se almacena la columna
			colTitulo.setCellValueFactory(new PropertyValueFactory<peliculasTableView,String>("titulo"));
			//Convierte el campo en editable
			colTitulo.setCellFactory(TextFieldTableCell.forTableColumn());
			colTitulo.setOnEditCommit(e->modificarTitulo(e));
			
			//Columna del año
			TableColumn<peliculasTableView,Integer> colAno = new TableColumn("Año");
			//Ancho columna
			colAno.setMinWidth(290);
			//Valor que se almacena la columna
			colAno.setCellValueFactory(new PropertyValueFactory<peliculasTableView,Integer>("ano"));
			//Convierte el campo en editable
			colAno.setCellFactory(TextFieldTableCell.forTableColumn(new IntegerStringConverter()));
			
			
			//Columna del precio
			TableColumn<peliculasTableView,Double> colPrecio = new TableColumn("Precio");
			//Ancho columna
			colPrecio.setMinWidth(290);
			//Valor que se almacena la columna
			colPrecio.setCellValueFactory(new PropertyValueFactory<peliculasTableView,Double>("precio"));
			//Convierte el campo en editable
			colPrecio.setCellFactory(TextFieldTableCell.forTableColumn(new DoubleStringConverter()));
			
			
			//Añadir columnas al tableview			
			TablaPeliculas.getColumns().addAll(colTitulo,colAno,colPrecio);
			
			
			Label lbTitulo = new Label("Título");
			Label lbAno = new Label("Año");
			Label lbPrecio = new Label("Precio");
			
			HBox panelRotulos = new HBox(lbTitulo,lbAno,lbPrecio);
			
			//Añadir textfields y boton
			txtTitulo = new TextField();
			txtAno = new TextField();
			txtPrecio = new TextField();
			
				
			btInsertar = new Button("Insertar");			
			btEliminar = new Button("Eliminar");
			btInsertar.setOnAction(e->insertarDatos());
			btEliminar.setOnAction(e->eliminarDatos());
			
			
			VBox panelTitulo = new VBox(lbTitulo,txtTitulo);
			VBox panelAno = new VBox(lbAno,txtAno);
			VBox panelPrecio = new VBox(lbPrecio,txtPrecio);

			
			HBox panelInsertar = new HBox(60,panelTitulo,panelAno,panelPrecio,btInsertar,btEliminar);
			panelInsertar.setPadding(new Insets(20,20,20,20));
			
			
			//Construir Pane Principal
			
			VBox panePrincipal = new VBox();
			panePrincipal.setPadding(new Insets(10,10,10,10));
			panePrincipal.getChildren().addAll(lblCabecera,TablaPeliculas,panelInsertar);
						
			
			//creando Scene
			Scene miScene=new Scene(panePrincipal);
			primaryStage.setScene(miScene);
			primaryStage.setTitle("Listado de películas");
			primaryStage.setResizable(true);
			primaryStage.show();
			
			
		} catch (Exception e) {
			e.printStackTrace();
		}
		
	}
	
	private void modificarTitulo(CellEditEvent<peliculasTableView, String> e) {
		
		peliculasTableView p= e.getRowValue();
		
		p.setTitulo(e.getNewValue());

	}

	public ObservableList<peliculasTableView> cargaDatos() {		
		
		ObservableList<peliculasTableView> datos = FXCollections.observableArrayList();
		
		datos.add(new peliculasTableView("Heat",1995,29.95));
		datos.add(new peliculasTableView("ET",1995,29.95));
		datos.add(new peliculasTableView("Gladiator",2000,29.95));
		
		
		return datos;
		
	}
	
	void insertarDatos() {
		
		
		peliculasTableView nuevoTitulo = new peliculasTableView();
				
				
			
			nuevoTitulo.setTitulo(txtTitulo.getText());				
			nuevoTitulo.setAno(Integer.parseInt(txtAno.getText()));	
			nuevoTitulo.setPrecio(Double.parseDouble(txtPrecio.getText()));
			
			
			TablaPeliculas.getItems().add(nuevoTitulo);
		
		
		
		
		
		
		
		txtTitulo.clear();
		txtAno.clear();
		txtPrecio.clear();
		
	
		
	}
	
	void eliminarDatos() {
		
		ObservableList<peliculasTableView> seleccionados = TablaPeliculas.getSelectionModel().getSelectedItems();
		ObservableList<peliculasTableView> peliculas = TablaPeliculas.getItems();
		
		for (peliculasTableView p : seleccionados) {
			
			peliculas.remove(p);		
			
		}	
				
	}
	
	
	
	public static void main(String[] args) {
		launch(args);
	}
	
	
	TextField txtTitulo,txtAno,txtPrecio;
	Button btInsertar,btEditar,btEliminar;
	TableView<peliculasTableView> TablaPeliculas;
}
